timespantools.SimpleInequality
==============================

.. abjad-lineage:: abjad.tools.timespantools.SimpleInequality.SimpleInequality

.. autoclass:: abjad.tools.timespantools.SimpleInequality.SimpleInequality

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality.evaluate
      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality.evaluate_offset_inequality
      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality.get_offset_indices
      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality.template
      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality.__eq__
      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality.__format__
      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality.__hash__
      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality.__ne__
      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.timespantools.SimpleInequality.SimpleInequality.template
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timespantools.SimpleInequality.SimpleInequality.evaluate
   :noindex:

.. automethod:: abjad.tools.timespantools.SimpleInequality.SimpleInequality.evaluate_offset_inequality
   :noindex:

.. automethod:: abjad.tools.timespantools.SimpleInequality.SimpleInequality.get_offset_indices
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.timespantools.SimpleInequality.SimpleInequality.__eq__
   :noindex:

.. automethod:: abjad.tools.timespantools.SimpleInequality.SimpleInequality.__format__
   :noindex:

.. automethod:: abjad.tools.timespantools.SimpleInequality.SimpleInequality.__hash__
   :noindex:

.. automethod:: abjad.tools.timespantools.SimpleInequality.SimpleInequality.__ne__
   :noindex:

.. automethod:: abjad.tools.timespantools.SimpleInequality.SimpleInequality.__repr__
   :noindex:
